@@ -344,19 +344,21 @@ prompt_response_cb (GtkWidget *dialog, int response, GvmPromptCtx *ctx)
 			warn ("Unable to run help uri: %s", err->message);
 			g_error_free (err);
 		}
-	} else {
-		checkbox = g_object_get_data ((GObject *) dialog, "checkbox");
-		if (checkbox && gtk_toggle_button_get_active (checkbox) && response != GTK_RESPONSE_CANCEL) {
-			gconf = gconf_client_get_default ();
-			gconf_client_set_int (gconf, gvm_prompts[ctx->prompt].ask_again_key, response, NULL);
-			g_object_unref (gconf);
-		}
 		
-		g_hash_table_remove (dialogs, ctx->udi);
-		ctx->callback (ctx, response);
-		gtk_widget_destroy (dialog);
-		gvm_prompt_ctx_free (ctx);
+		return;
 	}
+	
+	checkbox = g_object_get_data ((GObject *) dialog, "checkbox");
+	if (checkbox && gtk_toggle_button_get_active (checkbox) && response != GTK_RESPONSE_CANCEL) {
+		gconf = gconf_client_get_default ();
+		gconf_client_set_int (gconf, gvm_prompts[ctx->prompt].ask_again_key, response, NULL);
+		g_object_unref (gconf);
+	}
+	
+	g_hash_table_remove (dialogs, ctx->udi);
+	ctx->callback (ctx, response);
+	gtk_widget_destroy (dialog);
+	gvm_prompt_ctx_free (ctx);
 }
 
 static char *
@@ -414,7 +416,7 @@ gvm_prompt (GvmPromptCtx *ctx, int argc, char **argv)
 	
 	gconf = gconf_client_get_default ();
 	
-	/* don't prompt the user again if she's already chosen a default action and has asked to not be prompetd again */
+	/* don't prompt the user again if she's already chosen a default action and has asked to not be prompted again */
 	if (gvm_prompts[prompt].ask_again_key) {
 		response = gconf_client_get_int (gconf, gvm_prompts[prompt].ask_again_key, &err);
 		if (response > GVM_RESPONSE_NONE && err == NULL) {
@@ -1149,7 +1151,7 @@ gvm_autorun (const char *udi, const char *device, const char *mount_point)
 			char *path;
 			
 			path = g_strdup_printf ("%s/%s", mount_point, autorun[i]);
-			if (access (path, X_OK)) {
+			if (access (path, F_OK | R_OK | X_OK) != 0) {
 				g_free (path);
 				continue;
 			}
@@ -1297,7 +1299,7 @@ gvm_device_mount (const char *udi, gboolean interactive)
 	
 	dbg ("mounting %s...\n", udi);
 	
-	if (!gnome_mount || access (gnome_mount, F_OK | X_OK) != 0) {
+	if (!gnome_mount || access (gnome_mount, F_OK | R_OK | X_OK) != 0) {
 		g_free (gnome_mount);
 		gnome_mount = g_find_program_in_path ("gnome-mount");
 	}
@@ -1419,7 +1421,7 @@ gvm_device_unmount (const char *udi)
 	
 	dbg ("unmounting %s...\n", udi);
 	
-	if (!gnome_mount || access (gnome_mount, F_OK | X_OK) != 0) {
+	if (!gnome_mount || access (gnome_mount, F_OK | R_OK | X_OK) != 0) {
 		g_free (gnome_mount);
 		gnome_mount = g_find_program_in_path ("gnome-mount");
 	}
@@ -1780,8 +1782,14 @@ block_device_added (const char *udi, const char *capability __attribute__((__unu
 	
 	if (mountable) {
 		/* only mount if the block device has a sensible filesystem */
-		fsusage = libhal_device_get_property_string (hal_ctx, udi, "volume.fsusage", &error);
-		if (!fsusage || strcmp (fsusage, "filesystem") != 0) {
+		if (!(fsusage = libhal_device_get_property_string (hal_ctx, udi, "volume.fsusage", &error))) {
+			dbg ("unable to get fsusage for %s: %s\n", udi, error.message);
+			mountable = FALSE;
+		} else if (!strcmp (fsusage, "crypto")) {
+			dbg ("encrypted volume found: %s\n", udi);
+			/* TODO: handle encrypted volumes */
+			mountable = FALSE;
+		} else if (strcmp (fsusage, "filesystem") != 0) {
 			dbg ("no sensible filesystem for %s\n", udi);
 			mountable = FALSE;
 		}
@@ -2149,7 +2157,7 @@ gvm_device_eject (const char *udi)
 	
 	dbg ("ejecting %s...\n", volume);
 	
-	if (!gnome_mount || access (gnome_mount, F_OK | X_OK) != 0) {
+	if (!gnome_mount || access (gnome_mount, F_OK | R_OK | X_OK) != 0) {
 		g_free (gnome_mount);
 		gnome_mount = g_find_program_in_path ("gnome-mount");
 	}
@@ -2477,93 +2485,40 @@ gvm_user_active_at_console (void)
 }
 
 
-static gboolean print_version;
-static const char *daemon_arg;
-static gboolean no_daemon;
-static gboolean secret_mode;
-
-#ifdef GNOME_PARAM_GOPTION_CONTEXT
-static GOptionEntry options[] = {
-	{ "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_NONE, &print_version,
-	  N_("Print version and exit"), NULL },
-	{ "daemon", 'd', G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_STRING, (char **) &daemon_arg,
-	  N_("Run as a daemon"), "<yes|no>" },
-	{ "no-daemon", 'n', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_NONE, &no_daemon,
-	  N_("Don't run as a daemon"), NULL },
-	{ "secret-mode", 's', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_NONE, &secret_mode,
-	  N_("Run in secret mode"), NULL },
-	{ NULL, '\0', 0, 0, NULL, NULL, NULL}
-};
-
-#else
+static gboolean print_version = FALSE;
+static const char *daemon_arg = NULL;
+static gboolean no_daemon = FALSE;
+static gboolean secret_mode = FALSE;
 
 static const struct poptOption options[] = {
-	{ "version", 'v', POPT_ARG_NONE | POPT_ARGFLAG_ONEDASH, NULL, 'v',
+	{ "version", 'v', POPT_ARG_NONE | POPT_ARGFLAG_ONEDASH, &print_version, 'v',
 	  N_("Print version and exit"), NULL },
-	{ "daemon", 'd', POPT_ARG_STRING | POPT_ARGFLAG_ONEDASH, NULL, 'd',
+	{ "daemon", 'd', POPT_ARG_STRING | POPT_ARGFLAG_ONEDASH, (char **) &daemon_arg, 'd',
 	  N_("Run as a daemon"), "<yes|no>" },
-	{ "no-daemon", 'n', POPT_ARG_NONE | POPT_ARGFLAG_ONEDASH, NULL, 'n',
+	{ "no-daemon", 'n', POPT_ARG_NONE | POPT_ARGFLAG_ONEDASH, &no_daemon, 'n',
 	  N_("Don't run as a daemon"), NULL },
-	{ "secret-mode", 's', POPT_ARG_NONE | POPT_ARGFLAG_ONEDASH, NULL, 's',
+	{ "secret-mode", 's', POPT_ARG_NONE | POPT_ARGFLAG_ONEDASH, &secret_mode, 's',
 	  N_("Run in secret mode"), NULL },
 	{ NULL, '\0', 0, NULL, '\0', NULL, NULL }
 };
-#endif
+
 
 int
-main (int argc, char *argv[])
+main (int argc, char **argv)
 {
 	gboolean daemonize = TRUE;
 	GnomeProgram *program;
 	GnomeClient *client;
-#ifdef GNOME_PARAM_GOPTION_CONTEXT
-	GOptionContext *ctx;
-#else
-	poptContext ctx;
-	int rc;
-#endif
 	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
 	
-#ifdef GNOME_PARAM_GOPTION_CONTEXT
-	ctx = g_option_context_new (PACKAGE);
-	g_option_context_add_main_entries (ctx, options, NULL);
-#endif
-	
 	program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
-#ifdef GNOME_PARAM_GOPTION_CONTEXT
-				      GNOME_PARAM_GOPTION_CONTEXT, ctx,
-#else
 				      GNOME_PARAM_POPT_FLAGS, POPT_CONTEXT_POSIXMEHARDER,
 				      GNOME_PARAM_POPT_TABLE, options,
-#endif
 				      GNOME_PARAM_NONE);
 	
-#ifndef GNOME_PARAM_GOPTION_CONTEXT
-	g_object_get ((GObject *) program, GNOME_PARAM_POPT_CONTEXT, &ctx, NULL);
-
-	poptResetContext (ctx);
-	
-	while ((rc = poptGetNextOpt (ctx)) > 0) {
-		switch (rc) {
-		case 'v':
-			print_version = TRUE;
-			break;
-		case 'd':
-			daemon_arg = poptGetOptArg (ctx);
-			break;
-		case 'n':
-			no_daemon = TRUE;
-			break;
-		case 's':
-			secret_mode = TRUE;
-			break;
-		}
-	}
-#endif
-	
 	if (print_version) {
 		fprintf (stdout, "%s version %s\n", PACKAGE, VERSION);
 		exit (0);
@@ -2575,7 +2530,7 @@ main (int argc, char *argv[])
 		else if (!strcmp (daemon_arg, "no") || !strcmp (daemon_arg, "false"))
 			daemonize = FALSE;
 		else
-			fprintf (stdout, _("Unrecogonized --daemon argument: %s\n"), daemon_arg);
+			fprintf (stdout, _("Unrecognized --daemon argument: %s\n"), daemon_arg);
 	}
 	
 	if (no_daemon)
